/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                              **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2011 - 2012
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                                  EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2012_Alum_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2012_Alum_Cuest.txt
/*         as como el archivo Excale09_2012_Alum_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2012_Alum_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2012_Alum_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MARZO DEL 2014
/*
/*  ****************************************************************************/




LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2012_Alum_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $entestF    "999999"  = "Respuesta omitida";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edad_acF    98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadCF      1         = "14 aos o menos"
                       2         = "15 aos"
                       3         = "16 aos"
                       4         = "17 aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadNF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edadAF      0         = "Sin edad anticipada"
                       1         = "Edad anticipada"
                       9         = "Respuesta omitida";
     VALUE edadEF      0         = "Sin extra edad severa"
                       1         = "Extra edad severa"
                       9         = "Respuesta omitida";
     VALUE reactF      0         = "Fallo"
                       1         = "Acierto"
                       5         = "Reactivo no alcanzado (se considera como no administrado)"
                       6         = "Reactivo no administrado por error de impresin"
                       7         = "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE R1_2F       97        = "Fuera de rango o ilegible"
                       99        = "Respuesta omitida";
     VALUE R3F         9997      = "Fuera de rango o ilegible"
                       9999      = "Respuesta omitida";
     VALUE R4_5F       97        = "Fuera de rango o ilegible"
                       99        = "Respuesta omitida";
     VALUE R6F         7         = "Fuera de rango o ilegible"
                       9         = "Respuesta omitida";
     VALUE R7_9F       97        = "Fuera de rango o ilegible"
                       99        = "Respuesta omitida";
     VALUE R10_12F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R13F        0         = "El espaol"
                       1         = "Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       2         = "Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R14F        0         = "No s/No tengo mam"
                       1         = "No fue a la escuela"
                       2         = "Primaria"
                       3         = "Secundaria"
                       4         = "Bachillerato o preparatoria"
                       5         = "Carrera tcnica"
                       6         = "Licenciatura o carrera universitaria"
                       7         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R15F        0         = "No s/No tengo pap"
                       1         = "No fue a la escuela"
                       2         = "Primaria"
                       3         = "Secundaria"
                       4         = "Bachillerato o preparatoria"
                       5         = "Carrera tcnica"
                       6         = "Licenciatura o carrera universitaria"
                       7         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R16F        0         = "Secundaria"
                       1         = "Bachillerato o preparatoria"
                       2         = "Carrera tcnica"
                       3         = "Licenciatura o carrera universitaria"
                       4         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R17F        0         = "No s"
                       1         = "Secundaria"
                       2         = "Bachillerato o preparatoria"
                       3         = "Carrera tcnica"
                       4         = "Licenciatura o carrera universitaria"
                       5         = "Posgrado (maestra o doctorado)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R18F        0         = "Pblica (de gobierno)"
                       1         = "Privada (de paga, particular)"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R19_23F     1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R24_30F     0         = "Nunca o casi nunca"
                       1         = "Pocas veces"
                       2         = "Muchas veces"
                       3         = "Casi siempre o siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE R31_38F     3         = "Nunca o casi nunca"
                       2         = "Pocas veces"
                       1         = "Muchas veces"
                       0         = "Casi siempre o siempre"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
RUN;






DATA INEE.Excale09_2012_Alum_Cuest;
   LENGTH
       NACIONAL         3
       ESCUELA          4
       ID_ENT           3
       NOM_ENT          $19
       ID_MOD           3
       MOD              $4
       ESTRATO          $6
       ENTEST           $6
       ALUMNO           5
       ID_INSTR         $15
       SEXO             3
       EDAD_AC          3
       MES_NAC          3
       EDAD             8
       EDAD_ACC         3
       EDAD_N           3
       EDAD_ANT         3
       EDAD_EES         3
       W_ALU            8
       AS001            3
       AS002            3
       AS003            4
       AS004            3
       AS005            3
       AS006            3
       AS007            3
       AS008            3
       AS009            3
       AS010            3
       AS011            3
       AS012            3
       AS013            3
       AS014            3
       AS015            3
       AS016            3
       AS017            3
       AS018            3
       AS019            3
       AS020            3
       AS021            3
       AS022            3
       AS023            3
       AS024            3
       AS025            3
       AS026            3
       AS027            3
       AS028            3
       AS029            3
       AS030            3
       AS031            3
       AS032            3
       AS033            3
       AS034            3
       AS035            3
       AS036            3
       AS037            3
       AS038            3
       WVARSTRR         3
       W_FSTR1          8
       W_FSTR2          8
       W_FSTR3          8
       W_FSTR4          8
       W_FSTR5          8
       W_FSTR6          8
       W_FSTR7          8
       W_FSTR8          8
       W_FSTR9          8
       W_FSTR10         8
       W_FSTR11         8
       W_FSTR12         8
       W_FSTR13         8
       W_FSTR14         8
       W_FSTR15         8
       W_FSTR16         8
       W_FSTR17         8
       W_FSTR18         8
       W_FSTR19         8
       W_FSTR20         8
       W_FSTR21         8
       W_FSTR22         8
       W_FSTR23         8
       W_FSTR24         8
       W_FSTR25         8
       W_FSTR26         8
       W_FSTR27         8
       W_FSTR28         8
       W_FSTR29         8
       W_FSTR30         8
       W_FSTR31         8
       W_FSTR32         8
       W_FSTR33         8
       W_FSTR34         8
       W_FSTR35         8
       W_FSTR36         8
       W_FSTR37         8
       W_FSTR38         8
       W_FSTR39         8
       W_FSTR40         8
       W_FSTR41         8
       W_FSTR42         8
       W_FSTR43         8
       W_FSTR44         8
       W_FSTR45         8
       W_FSTR46         8
       W_FSTR47         8
       W_FSTR48         8
       W_FSTR49         8
       W_FSTR50         8
       W_FSTR51         8
       W_FSTR52         8
       W_FSTR53         8
       W_FSTR54         8
       W_FSTR55         8
       W_FSTR56         8
       W_FSTR57         8
       W_FSTR58         8
       W_FSTR59         8
       W_FSTR60         8
       W_FSTR61         8
       W_FSTR62         8
       W_FSTR63         8
       W_FSTR64         8
       W_FSTR65         8
       W_FSTR66         8
       W_FSTR67         8
       W_FSTR68         8
       W_FSTR69         8
       W_FSTR70         8
       W_FSTR71         8
       W_FSTR72         8
       W_FSTR73         8
       W_FSTR74         8
       W_FSTR75         8
       W_FSTR76         8
       W_FSTR77         8
       W_FSTR78         8
       W_FSTR79         8
       W_FSTR80         8
       W_FSTR81         8
       W_FSTR82         8
       W_FSTR83         8
       W_FSTR84         8
       W_FSTR85         8
       W_FSTR86         8
       W_FSTR87         8
       W_FSTR88         8
       W_FSTR89         8
       W_FSTR90         8
       W_FSTR91         8
       W_FSTR92         8
       W_FSTR93         8
       W_FSTR94         8
       W_FSTR95         8
       W_FSTR96         8
       W_FSTR97         8
       W_FSTR98         8
       W_FSTR99         8
       W_FSTR100        8
;





INFILE alum MISSOVER LINESIZE = 1245;
   INPUT
       NACIONAL           1 - 1
       ESCUELA            2 - 5
       ID_ENT             6 - 7
       NOM_ENT            8 - 26
       ID_MOD            27 - 27
       MOD               28 - 31
       ESTRATO           32 - 37
       ENTEST            38 - 43
       ALUMNO            44 - 48
       ID_INSTR          49 - 63
       SEXO              64 - 64
       EDAD_AC           65 - 66
       MES_NAC           67 - 68
       EDAD              69 - 79
       EDAD_ACC          80 - 80
       EDAD_N            81 - 81
       EDAD_ANT          82 - 82
       EDAD_EES          83 - 83
       W_ALU             84 - 94
       AS001             95 - 96
       AS002             97 - 98
       AS003             99 - 102
       AS004            103 - 104
       AS005            105 - 106
       AS006            107 - 107
       AS007            108 - 109
       AS008            110 - 111
       AS009            112 - 113
       AS010            114 - 114
       AS011            115 - 115
       AS012            116 - 116
       AS013            117 - 117
       AS014            118 - 118
       AS015            119 - 119
       AS016            120 - 120
       AS017            121 - 121
       AS018            122 - 122
       AS019            123 - 123
       AS020            124 - 124
       AS021            125 - 125
       AS022            126 - 126
       AS023            127 - 127
       AS024            128 - 128
       AS025            129 - 129
       AS026            130 - 130
       AS027            131 - 131
       AS028            132 - 132
       AS029            133 - 133
       AS030            134 - 134
       AS031            135 - 135
       AS032            136 - 136
       AS033            137 - 137
       AS034            138 - 138
       AS035            139 - 139
       AS036            140 - 140
       AS037            141 - 141
       AS038            142 - 142
       WVARSTRR         143 - 145
       W_FSTR1          146 - 156
       W_FSTR2          157 - 167
       W_FSTR3          168 - 178
       W_FSTR4          179 - 189
       W_FSTR5          190 - 200
       W_FSTR6          201 - 211
       W_FSTR7          212 - 222
       W_FSTR8          223 - 233
       W_FSTR9          234 - 244
       W_FSTR10         245 - 255
       W_FSTR11         256 - 266
       W_FSTR12         267 - 277
       W_FSTR13         278 - 288
       W_FSTR14         289 - 299
       W_FSTR15         300 - 310
       W_FSTR16         311 - 321
       W_FSTR17         322 - 332
       W_FSTR18         333 - 343
       W_FSTR19         344 - 354
       W_FSTR20         355 - 365
       W_FSTR21         366 - 376
       W_FSTR22         377 - 387
       W_FSTR23         388 - 398
       W_FSTR24         399 - 409
       W_FSTR25         410 - 420
       W_FSTR26         421 - 431
       W_FSTR27         432 - 442
       W_FSTR28         443 - 453
       W_FSTR29         454 - 464
       W_FSTR30         465 - 475
       W_FSTR31         476 - 486
       W_FSTR32         487 - 497
       W_FSTR33         498 - 508
       W_FSTR34         509 - 519
       W_FSTR35         520 - 530
       W_FSTR36         531 - 541
       W_FSTR37         542 - 552
       W_FSTR38         553 - 563
       W_FSTR39         564 - 574
       W_FSTR40         575 - 585
       W_FSTR41         586 - 596
       W_FSTR42         597 - 607
       W_FSTR43         608 - 618
       W_FSTR44         619 - 629
       W_FSTR45         630 - 640
       W_FSTR46         641 - 651
       W_FSTR47         652 - 662
       W_FSTR48         663 - 673
       W_FSTR49         674 - 684
       W_FSTR50         685 - 695
       W_FSTR51         696 - 706
       W_FSTR52         707 - 717
       W_FSTR53         718 - 728
       W_FSTR54         729 - 739
       W_FSTR55         740 - 750
       W_FSTR56         751 - 761
       W_FSTR57         762 - 772
       W_FSTR58         773 - 783
       W_FSTR59         784 - 794
       W_FSTR60         795 - 805
       W_FSTR61         806 - 816
       W_FSTR62         817 - 827
       W_FSTR63         828 - 838
       W_FSTR64         839 - 849
       W_FSTR65         850 - 860
       W_FSTR66         861 - 871
       W_FSTR67         872 - 882
       W_FSTR68         883 - 893
       W_FSTR69         894 - 904
       W_FSTR70         905 - 915
       W_FSTR71         916 - 926
       W_FSTR72         927 - 937
       W_FSTR73         938 - 948
       W_FSTR74         949 - 959
       W_FSTR75         960 - 970
       W_FSTR76         971 - 981
       W_FSTR77         982 - 992
       W_FSTR78         993 - 1003
       W_FSTR79        1004 - 1014
       W_FSTR80        1015 - 1025
       W_FSTR81        1026 - 1036
       W_FSTR82        1037 - 1047
       W_FSTR83        1048 - 1058
       W_FSTR84        1059 - 1069
       W_FSTR85        1070 - 1080
       W_FSTR86        1081 - 1091
       W_FSTR87        1092 - 1102
       W_FSTR88        1103 - 1113
       W_FSTR89        1114 - 1124
       W_FSTR90        1125 - 1135
       W_FSTR91        1136 - 1146
       W_FSTR92        1147 - 1157
       W_FSTR93        1158 - 1168
       W_FSTR94        1169 - 1179
       W_FSTR95        1180 - 1190
       W_FSTR96        1191 - 1201
       W_FSTR97        1202 - 1212
       W_FSTR98        1213 - 1223
       W_FSTR99        1224 - 1234
       W_FSTR100       1235 - 1245
;






LABEL
      NACIONAL       = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA        = "Identificador de la escuela"
      ID_ENT         = "Entidad federativa (identificador numrico)"
      NOM_ENT        = "Entidad federativa"
      ID_MOD         = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD            = "Estrato escolar o Modalidad educativa"
      ESTRATO        = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST         = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO         = "Identificador del alumno"
      ID_INSTR       = "Identificador del cuadernillo de examen"
      SEXO           = "Sexo del alumno"
      EDAD_AC        = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC        = "Mes de nacimiento del alumno"
      EDAD           = "Edad del alumno al mes de mayo de 2012, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC       = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N         = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT       = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES       = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU          = "Peso muestral o ponderador del alumno"
      AS001          = "Incluyndote, cuntas personas viven en tu casa?"
      AS002          = "En tu casa, cuntos cuartos se utilizan para dormir?"
      AS003          = "Aproximadamente, cuntos libros hay en tu casa? (No incluyas revistas, peridicos, ni tus libros escolares) Si no hay libros, escribe 0"
      AS004          = "Durante la semana pasada, cuntas horas dedicaste a ayudar a tu familia en alguna actividad sin recibir pago alguno? (Labores domsticas, atender un negocio familiar, labores del campo u otras) Si no lo hiciste, escribe 0"
      AS005          = "Durante la semana pasada, cuntas horas realizaste un trabajo por el que recibiste algn pago? Si no lo hiciste, escribe 0"
      AS006          = "Cuntas veces repetiste algn grado en la primaria? Si no repetiste, escribe 0"
      AS007          = "Cuntas materias reprobaste en primero y segundo de secundaria? Si no reprobaste, escribe 0"
      AS008          = "Cuntas veces saliste con tu familia a vacacionar en los ltimos dos aos? Si no vacacionaron, escribe 0"
      AS009          = "Cuntos automviles tienen en tu casa? Si no tienen, escribe 0"
      AS010          = "Tienen agua entubada en tu casa todos los das?"
      AS011          = "Hay telfono en tu casa?"
      AS012          = "Hay computadora en tu casa?"
      AS013          = "Qu lengua aprendiste a hablar primero?"
      AS014          = "Cul es el nivel mximo de estudios que concluy tu mam?"
      AS015          = "Cul es el nivel mximo de estudios que concluy tu pap?"
      AS016          = "Hasta qu nivel educativo te gustara estudiar?"
      AS017          = "Hasta qu nivel educativo les gustara a tus padres que estudiaras?"
      AS018          = "De qu tipo era la escuela primaria donde estudiaste?"
      AS019          = "En la primaria donde estudiaste, utilizaban libros de texto en lengua indgena?"
      AS020          = "La primaria donde estudiaste era del Conafe (cursos comunitarios)?"
      AS021          = "En la primaria donde estudiaste, estuviste en algn grupo en que un mismo maestro enseaba a alumnos de varios grados al mismo tiempo?"
      AS022          = "Haba algn hospital en el mismo pueblo, ciudad o comunidad donde estudiaste la primaria? (No tomes en cuenta clnicas ni centros de salud)"
      AS023          = "Estudiaste la primaria en el mismo pueblo, ciudad o comunidad donde ahora estudias la secundaria?"
      AS024          = "Tus padres te ayudan a hacer la tarea cuando lo necesitas?"
      AS025          = "Tus padres estn al tanto de los materiales que necesitas para la escuela?"
      AS026          = "Tus padres estn al tanto de tus calificaciones?"
      AS027          = "Cuando no entiendes algo en clase, buscas ms informacin fuera de la escuela, o le preguntas a otras personas?"
      AS028          = "Cuando te interesa algo que aprendiste en clase, buscas ms informacin fuera de la escuela, o le preguntas a otras personas?"
      AS029          = "Cuando tus maestros te dejan actividades que no cuentan para tu calificacin, las realizas?"
      AS030          = "Lo que aprendes en la escuela, te ayuda en tu vida diaria?"
      AS031          = "Con qu frecuencia tu profesor de Matemticas realiza estas acciones?: Falta a la clase"
      AS032          = "Con qu frecuencia tu profesor de Matemticas realiza estas acciones?: Llega tarde a la clase"
      AS033          = "Con qu frecuencia tu profesor de Matemticas realiza estas acciones?: Deja solo al grupo durante la clase"
      AS034          = "Con qu frecuencia tu profesor de Matemticas realiza estas acciones?: Deja al grupo hacer lo que quiera mientras l hace otras cosas"
      AS035          = "Con qu frecuencia tu profesor de Matemticas realiza estas acciones?: Interrumpe su clase por mala conducta de los alumnos"
      AS036          = "Con qu frecuencia ocurren estas situaciones en tu clase de Matemticas?: Se hacen actividades ajenas a la enseanza de las matemticas"
      AS037          = "Con qu frecuencia ocurren estas situaciones en tu clase de Matemticas?: Personas ajenas al grupo interrumpen la clase"
      AS038          = "Con qu frecuencia ocurren estas situaciones en tu clase de Matemticas?: Pasamos mucho tiempo de la clase sin trabajo que hacer"
      WVARSTRR       = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9        = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99       = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100      = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;






FORMAT
       NACIONAL          1.
       ESCUELA           4.
       ID_ENT            id_entF.
       NOM_ENT           $char19.
       ID_MOD            id_modF.
       MOD               $modF.
       ESTRATO           $char6.
       ENTEST            $entestF.
       ALUMNO            5.
       ID_INSTR          $char16.
       SEXO              sexoF.
       EDAD_AC           edad_acF.
       MES_NAC           mes_nacF.
       EDAD              edadF.
       EDAD_ACC          edadCF.
       EDAD_N            edadNF.
       EDAD_ANT          edadAF.
       EDAD_EES          edadEF.
       AS001             R1_2F.
       AS002             R1_2F.
       AS003             R3F.
       AS004             R4_5F.
       AS005             R4_5F.
       AS006             R6F.
       AS007             R7_9F.
       AS008             R7_9F.
       AS009             R7_9F.
       AS010             R10_12F.
       AS011             R10_12F.
       AS012             R10_12F.
       AS013             R13F.
       AS014             R14F.
       AS015             R15F.
       AS016             R16F.
       AS017             R17F.
       AS018             R18F.
       AS019             R19_23F.
       AS020             R19_23F.
       AS021             R19_23F.
       AS022             R19_23F.
       AS023             R19_23F.
       AS024             R24_30F.
       AS025             R24_30F.
       AS026             R24_30F.
       AS027             R24_30F.
       AS028             R24_30F.
       AS029             R24_30F.
       AS030             R24_30F.
       AS031             R31_38F.
       AS032             R31_38F.
       AS033             R31_38F.
       AS034             R31_38F.
       AS035             R31_38F.
       AS036             R31_38F.
       AS037             R31_38F.
       AS038             R31_38F.
       wvarstrr          3.
;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = Fuera de rango o ilegible.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  entest = "999999" THEN  entest = .S;


   ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
   DO  i=1 TO 5;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  AS003 = 9997 THEN  AS003 = .N;
   IF  AS003 = 9999 THEN  AS003 = .S;

   IF  AS006 = 7 THEN  AS006 = .N;
   IF  AS006 = 9 THEN  AS006 = .S;


   ARRAY perdidos3(7)  AS001 AS002 AS004 AS005 AS007 AS008 AS009;
   DO  i=1 TO 7;
         IF perdidos3{i}=97 THEN  perdidos3{i}= .N;
         IF perdidos3{i}=99 THEN  perdidos3{i}= .S;
   END;


   ARRAY perdidos4(28)
                 AS010 AS011 AS012 AS013 AS014 AS015 AS016 AS017 AS018 AS019
                 AS020 AS021 AS022 AS023 AS024 AS025 AS026 AS027 AS028 AS029
                 AS030 AS031 AS032 AS033 AS034 AS035 AS036 AS037;
   DO  i=1 TO 28;
          IF perdidos4{i} = 8   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 9   THEN  perdidos4{i} = .S;
   END;

   drop i;
RUN;
